import React, { useRef, useState } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer2";
import Reference from "../../components/Reference";
import image from "../../assets/images/info_media/menu31/image.png";

import { Content, StyledContainer } from "./styles";

export default function () {
    const headerref = useRef(Header);
    const openRef = (key) => {
        if (!headerref.current) {
            return;
        }

        headerref.current.openRef(key);
    };

    const [abaSelecionada, setAbaSelecionada] = useState(0);

    const textos = [
        <p key="0">
            São formadas precocemente placas e pápulas urticariformes lineares,
            podendo evoluir com flictenas e necrose extensa nas próximas 24
            horas
            <Reference num="1" onClick={() => openRef(1)} />.
        </p>,
        <p key="1">
            Nos acidentes leves, as lesões urticariformes regridem, com
            persistência de lesões eritematosas lineares que podem permanecer no
            local por meses
            <Reference num="1" onClick={() => openRef(1)} />.
        </p>,
        <p key="2">
            As manifestações nos casos graves envolvem cefaleia, náuseas,
            vômitos, espasmos musculares, febre e arritmia, sendo que a
            gravidade está diretamente relacionada com a extensão da área
            comprometida. É possível o surgimento de urticárias e erupções
            recorrentes e reações distantes da área do acidente.
        </p>,
        <p key="3">
            Nos casos em que ocorre a ingestão desses animais, podem estar
            presentes sintomas gastrointestinais alérgicos e quadros
            urticariformes
            <Reference num="1" onClick={() => openRef(1)} />.
        </p>,
    ];

    return (
        <StyledContainer>
            <Header ref={headerref} />
            <Box className="container">
                <Content>
                    <Box className="title">
                        <Typography variant="h5" align="center">
                            Acidentes provocados por caravelas e águas-vivas
                        </Typography>
                    </Box>
                    <Box className="content">
                        <div className="mt-4 texto-imagem">
                            <div className="texto">
                                <Typography variant="body1">
                                    <p>
                                        As caravelas são as responsáveis pelo
                                        maior número de acidentes graves
                                        causados por esse grupo no Brasil,
                                        seguidas pelas águas-vivas
                                        <Reference
                                            num="1"
                                            onClick={() => openRef(1)}
                                        />
                                        .
                                    </p>
                                    <p>
                                        As ocorrências são mais frequentes no
                                        verão, quando estes animais aquáticos
                                        podem ocupar as praias em grande número,
                                        gerando centenas de acidentes. As
                                        águas-vivas têm preferência pelas águas
                                        de fundo arenoso e estuários de rios,
                                        procurando as águas profundas nos
                                        momentos mais quentes do dia
                                        <Reference
                                            num="1"
                                            onClick={() => openRef(1)}
                                        />
                                        .
                                    </p>
                                    <p>
                                        As manifestações locais são marcadas por
                                        ardência e dor intensa no local, podendo
                                        durar de meia hora a 24 horas.{" "}
                                        <b>Clique</b> nos números e conheça as
                                        características das manifestações
                                        locais.
                                    </p>
                                </Typography>

                                <Box className="abas-texto">
                                    <div className="abas">
                                        <Typography
                                            variant="body1"
                                            className={`${
                                                abaSelecionada === 0 &&
                                                "abaSelecionada"
                                            }  `}
                                            onClick={() => setAbaSelecionada(0)}
                                        >
                                            1
                                        </Typography>
                                        <Typography
                                            variant="body1"
                                            className={`${
                                                abaSelecionada === 1 &&
                                                "abaSelecionada"
                                            }  `}
                                            onClick={() => setAbaSelecionada(1)}
                                        >
                                            2
                                        </Typography>
                                        <Typography
                                            variant="body1"
                                            className={`${
                                                abaSelecionada === 2 &&
                                                "abaSelecionada"
                                            }  `}
                                            onClick={() => setAbaSelecionada(2)}
                                        >
                                            3
                                        </Typography>
                                        <Typography
                                            variant="body1"
                                            className={`${
                                                abaSelecionada === 3 &&
                                                "abaSelecionada"
                                            }  `}
                                            onClick={() => setAbaSelecionada(3)}
                                        >
                                            4
                                        </Typography>
                                    </div>
                                    <div className="textoAbas">
                                        <Typography variant="body1">
                                            {textos[abaSelecionada]}
                                        </Typography>
                                    </div>
                                </Box>
                            </div>
                            <div className="imagem">
                                <img src={image} alt="caravela" />
                            </div>
                        </div>
                    </Box>
                </Content>
                <Footer next="/menu32" color="transparent" />
            </Box>
        </StyledContainer>
    );
}
