import React, { useRef, useState } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer2";
import button_close from "../../assets/buttons/btn_fechar.svg";
import tabela from "../../assets/images/info_media/tabelas/tabela3.png";
import pdf from "../../assets/images/info_media/tabelas/tabela3.pdf";

import { Content, StyledContainer } from "./styles";

export default function () {
    const headerref = useRef(Header);
    const openRef = (key) => {
        if (!headerref.current) {
            return;
        }

        headerref.current.openRef(key);
    };
    const [abaSelecionada, setAbaSelecionada] = useState(0);

    const sintomas = [
        <p key="0">
            Dor
            <br />
            Placas e pápulas urticariformes lineares
            <br />
            Flictenas e necrose
        </p>,
        <p key="1">
            Sintomas gastrointestinais alérgicos
            <br />
            Quadro urticariforme
        </p>,
        <p key="2">
            Cefaleia
            <br />
            Náuseas e Vômitos
            <br />
            Espasmos Musculares
            <br />
            Febre
            <br />
            Arritmia
        </p>,
        <p key="3">
            Anafilaxia (cefaleia, vertigem, dispneia, broncoespasmo, agitação
            psicomotora, prurido generalizado, urticária, angioedema,
            hipotensão, dor abdominal)
        </p>,
    ];
    const condutas = [
        <p key="0">
            Analgesia (dipirona/ paracetamol)
            <br />
            Anti-histamínico (loratadina/ dexclorfeniramina/prometazina)
            <br />
            Corticoide tópico (dexametasona)
            <br />
            Corticoide oral (prednisona)
        </p>,
        <p key="1">
            Anti-histamínico (loratadina/ dexclorfeniramina/prometazina)
            <br />
            Corticoide oral (prednisona)
            <br />
            Antiemético (metoclopramida)
            <br />
        </p>,
        <p key="2">
            Analgesia (dipirona/ paracetamol)
            <br />
            Antiemético (metoclopramida)
            <br />
            Corticoide (hidrocortisona/ prednisona)
            <br />
            Suporte clínico em unidade de urgência e emergência
        </p>,
        <p key="3">
            Adrenalina
            <br />
            Broncodilatador (salbutamol)
            <br />
            Analgesia (dipirona/ paracetamol)
            <br />
            Anti-histamínico (loratadina/ dexclorfeniramina/prometazina)
            <br />
            Corticoide (hidrocortisona/ prednisona)
            <br />
            Expansão de volume (Solução salina/ Ringer lactato)
            <br />
            Suporte clínico em unidade de urgência e emergência
        </p>,
    ];

    return (
        <StyledContainer>
            <Header ref={headerref} />
            <Box className="container">
                <Content>
                    <div className="top">
                        <Box className="title">
                            <Typography variant="h5" align="center">
                                Acidentes provocados por caravelas e águas-vivas
                            </Typography>
                        </Box>
                        <div className="button">
                            <a href="#/menu">
                                <img src={button_close} />
                            </a>
                        </div>
                    </div>
                    <Box className="content">
                        <Box className="text">
                            <Typography variant="body1">
                                <p>
                                    <b>Clique</b> nas manifestações clínicas de
                                    acidentes causados por caravelas e
                                    águas-vivas para observar os sintomas e as
                                    condutas adequadas.
                                </p>
                            </Typography>
                        </Box>
                        <div className="titleTable">
                            <Typography variant="body1">
                                <p>
                                    Manifestações Clínicas e Condutas – Acidentes provocados
                                    por caravelas e águas-vivas
                                </p>
                            </Typography>
                        </div>
                        <div className="subtitles">
                            <div className="subtitle1">
                                <Typography>
                                    <p>Manifestação</p>
                                </Typography>
                            </div>
                            <div className="subtitle2">
                                <Typography>
                                    <p>Sintomas</p>
                                </Typography>
                            </div>
                            <div className="subtitle3">
                                <Typography>
                                    <p>Condutas</p>
                                </Typography>
                            </div>
                        </div>
                        <Box className="abas-texto">
                            <div className="abas">
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 0 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(0)}
                                >
                                    Local
                                </Typography>
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 1 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(1)}
                                >
                                    Decorrente de Ingestão
                                </Typography>
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 2 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(2)}
                                >
                                    Grave
                                </Typography>
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 3 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(3)}
                                >
                                    Sistêmica
                                </Typography>
                            </div>
                            <div className="textoAbas">
                                <div className="sintomas">
                                    <Typography variant="body1" id="sintomas">
                                        {sintomas[abaSelecionada]}
                                    </Typography>
                                </div>

                                <div className="condutas">
                                    <Typography variant="body1">
                                        {condutas[abaSelecionada]}
                                    </Typography>
                                </div>
                            </div>
                        </Box>
                        <div className="imagem">
                            <a href={pdf} target="_blank">
                                <img src={tabela} />
                            </a>
                        </div>
                    </Box>
                </Content>
                <Footer prev="/menu33" color="transparent" />
            </Box>
        </StyledContainer>
    );
}
