import React, { useRef, useState } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer2";
import button_close from "../../assets/buttons/btn_fechar.svg";
import tabela from "../../assets/images/info_media/tabelas/tabela4.png";
import pdf from "../../assets/images/info_media/tabelas/tabela4.pdf";

import { Content, StyledContainer } from "./styles";

export default function () {
    const headerref = useRef(Header);
    const openRef = (key) => {
        if (!headerref.current) {
            return;
        }

        headerref.current.openRef(key);
    };
    const [abaSelecionada, setAbaSelecionada] = useState(0);

    const sintomas = [
        <p key="0">
            Urticária
            <br />
            Tremor
            <br />
            Tosse
            <br />
            Náuseas e Vômitos
            <br />
            Dor abdominal
            <br />
            Prurido <br />
            Rubor facial
        </p>,
        <p key="1">
            Anafilaxia (cefaleia, vertigem, dispneia, broncoespasmo, agitação
            psicomotora, prurido generalizado, urticária, angioedema,
            hipotensão, dor abdominal)
        </p>,
        <p key="2">
            Febre 
            <br/>
            Artralgia
            <br />
            Linfonodomegalia
            <br />
            Urticária
            <br />
            Proteinúria
        </p>,
    ];
    const condutas = [
        <p key="0">
            Analgesia (dipirona/ paracetamol)
            <br />
            Antiemético (metoclopramida)
            <br />
            Anti-histamínico (loratadina/ dexclorfeniramina/ prometazina)
            <br />
            Corticoide (prednisona/ hidrocortisona)
            <br />
            Observação por 24 horas
        </p>,
        <p key="1">
            Suspender a infusão da soroterapia
            <br />
            Adrenalina
            <br />
            Broncodilatador (salbutamol)
            <br />
            Analgesia (dipirona/ paracetamol)
            <br />
            Anti-histamínico (loratadina/ dexclorfeniramina/ prometazina)
            <br />
            Corticoide (hidrocortisona/ prednisona)
            <br />
            Expansão de volume (Solução salina/ Ringer lactato)
            <br />
            Após controle da reação anafilática reiniciar soroterapia com soro
            diluído e infusão mais lenta
        </p>,
        <p key="2">
            Analgesia (dipirona/ paracetamol)
            <br />
            Corticoide oral (prednisona)
        </p>,
    ];

    return (
        <StyledContainer>
            <Header ref={headerref} />
            <Box className="container">
                <Content>
                    <div className="top">
                        <Box className="title">
                            <Typography variant="h5" align="center">
                                Reações adversas à soroterapia
                            </Typography>
                        </Box>
                        <div className="button">
                            <a href="#/menu">
                                <img src={button_close} />
                            </a>
                        </div>
                    </div>
                    <Box className="content">
                        <Box className="text">
                            <Typography variant="body1">
                                <p>
                                    <b>Clique</b> nas manifestações clínicas de
                                    Reações adversas à soroterapia para observar
                                    os sintomas e condutas adequadas.
                                </p>
                            </Typography>
                        </Box>
                        <div className="titleTable">
                            <Typography variant="body1">
                                <p>
                                    Manifestações Clínicas e Condutas –
                                    Soroterapia
                                </p>
                            </Typography>
                        </div>
                        <div className="subtitles">
                            <div className="subtitle1">
                                <Typography>
                                    <p>Manifestação</p>
                                </Typography>
                            </div>
                            <div className="subtitle2">
                                <Typography>
                                    <p>Sintomas</p>
                                </Typography>
                            </div>
                            <div className="subtitle3">
                                <Typography>
                                    <p>Condutas</p>
                                </Typography>
                            </div>
                        </div>
                        <Box className="abas-texto">
                            <div className="abas">
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 0 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(0)}
                                >
                                    Precoce Leve
                                </Typography>
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 1 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(1)}
                                >
                                    Precoce Grave
                                </Typography>
                                <Typography
                                    variant="body1"
                                    className={`${
                                        abaSelecionada === 2 && "abaSelecionada"
                                    }  `}
                                    onClick={() => setAbaSelecionada(2)}
                                >
                                    Tardia - Doença do Soro (5 a 24 dias após
                                    soroterapia)
                                </Typography>
                            </div>
                            <div className="textoAbas">
                                <div className="sintomas">
                                    <Typography variant="body1" id="sintomas">
                                        {sintomas[abaSelecionada]}
                                    </Typography>
                                </div>

                                <div className="condutas">
                                    <Typography variant="body1">
                                        {condutas[abaSelecionada]}
                                    </Typography>
                                </div>
                            </div>
                        </Box>
                        <div className="imagem">
                            <a href={pdf} target="_blank">
                                <img src={tabela} />
                            </a>
                        </div>
                    </Box>
                </Content>
                <Footer prev="/menu47" color="transparent" />
            </Box>
        </StyledContainer>
    );
}
